1.13.3 — Rucio 1.2 documentation

# 1.13.3

## General

### Enhancements

- Documentation: General README #84
- Documentation: Minor fixes in the readme files #98
- Release management: Create-patch/next-branch script should make full reset of origin against next #113
- Testing: New submission script for github #8
- Testing: Add mysql testing to travis #91

### Bugs

- Documentation: documention: add link on AUTHORS from CONTRIBUTING.rst #106